/*
 * Copyright (C) 2022 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.eingang.semantik.enginebased.formsolutions;

import static de.ozgcloud.eingang.common.formdata.AntragstellerTestFactory.*;
import static de.ozgcloud.eingang.common.formdata.FormDataTestFactory.*;
import static de.ozgcloud.eingang.semantik.enginebased.formsolutions.FormSolutionsAntragstellerMapper.*;
import static de.ozgcloud.eingang.semantik.enginebased.formsolutions.FormSolutionsEngineBasedAdapter.*;
import static de.ozgcloud.eingang.semantik.enginebased.formsolutions.FormSolutionsPanelMapper.*;
import static org.assertj.core.api.Assertions.*;

import java.util.List;
import java.util.Map;

import org.junit.jupiter.api.Test;

import de.ozgcloud.eingang.common.formdata.FormData;
import de.ozgcloud.eingang.common.formdata.FormDataTestFactory;
import de.ozgcloud.eingang.semantik.enginebased.formsolutions.FormSolutionsHeaderMapper;
import de.ozgcloud.eingang.semantik.enginebased.formsolutions.IdentifierValueParser;

class IdentifierValueParserTest {

	private static final String ANTRAGSTELLER_NAME_PANEL_IDENTIFIER = "AS_Name1";
	private static final List<Map<String, Object>> ANTRAGSTELLER_PANEL_CONTENT_LIST = List.of(
			Map.of(IDENTIFIER_KEY, ANTRAGSTELLER_NAME_PANEL_IDENTIFIER),
			Map.of(COMPONENTS, List.of(
					Map.of(IDENTIFIER_KEY, VORNAME_KEY, STRING_VALUE, VORNAME),
					Map.of(IDENTIFIER_KEY, NACHNAME_KEY, STRING_VALUE, NACHNAME))));

	private static final Map<String, Object> ASSISTANT_MAP = Map.of(PANELS, List.of(
			Map.of(IDENTIFIER_KEY, ANTRAGSTELLER_PANEL_IDENTIFIER), Map.of(COMPONENTS, ANTRAGSTELLER_PANEL_CONTENT_LIST)));

	private FormData formData = FormDataTestFactory.createBuilder()
			.formData(Map.of(SIMPLE_VALUE_KEY, SIMPLE_VALUE,
					FormSolutionsHeaderMapper.POSTKORBHANDLE, POSTFACH_ID, ASSISTANT, ASSISTANT_MAP))
			.build();

	@Test
	void shoudParseData() {
		var expectedMap = Map.of(VORNAME_KEY, VORNAME, NACHNAME_KEY, NACHNAME);

		var stringValueMap = IdentifierValueParser.parsePanelsData(formData);

		assertThat(stringValueMap).isEqualTo(expectedMap);
	}

	@Test
	void shouldHandleNullPanels() {
		formData = FormDataTestFactory.createBuilder().formData(null).build();

		var stringValueMap = IdentifierValueParser.parsePanelsData(formData);

		assertThat(stringValueMap).isEmpty();
	}

}